@@ -70,6 +70,8 @@ class PyCompletionTest : public QObject
         void testIgnoreCommentSignsInStringLiterals();
         void testIdentifierMatching();
         void testAutoBrackets();
+        void testAddImportCompletion();
+        void testAddImportCompletion_data();
     private:
         QList<CompletionTreeItemPointer> m_ptrs;
 };
